'use strict';

var React = require('react-native');
import PropTypes from 'prop-types';
var BaseChartMixin = {
  propTypes: {
    /*
     * inherit all props from the View element
     */
    ...React.View.propTypes,

    /*
     * data to display with the graph
     */
    data: PropTypes.shape({
      dataSets: PropTypes.arrayOf(PropTypes.shape({
        /*
         * Array of values to display with the graph
         */
        values: PropTypes.arrayOf(PropTypes.number),

        /*
         */
        colors: PropTypes.arrayOf(PropTypes.string),

        /*
         * Should text labels be drawn for values
         */
        drawValues: PropTypes.bool,
      })),

      /*
       * Array of strings defining x-axis labels
       */
      xValues: PropTypes.arrayOf(PropTypes.string),
    }),

    /*
     * enable touch events on the chart
     */
    touchEnabled: PropTypes.bool,

    /*
     * event handler for when a value is selected
     */
    onValueSelect: PropTypes.func,

    /*
     * event handler when the selection is cleared
     */
    onClearSelection: PropTypes.func,
  },

  _onSelect: function(event){
    if (event.type === 'valueSelect' && this.props.onValueSelect){
      this.props.onValueSelect(event);
    }else if (event.type === 'clearSelection' && this.props.onClearSelection){
      this.props.onClearSelection(event);
    }
  },
};

module.exports = BaseChartMixin;
